@@ -27,7 +27,7 @@ class Sheets:
         return worksheet.get_all_values()
 
     def lertabmod(self,se):
-        ws = str(se)
+        ws = se.lower()
         worksheet = self.sh.worksheet(ws)
         lis = []
         for li in worksheet.col_values(2):
@@ -38,7 +38,7 @@ class Sheets:
         lista = lis.replace("['",'[')
         lista = lista.replace("']",']')
         lista = lista.replace("'",'')
-        return json.loads(lista)
+        return lista
 
     def __verificarigualdade(self,se):
         add, worksheet = addicionar(se)
@@ -51,7 +51,7 @@ class Sheets:
             if not (i in itensfiltrados):
                 itensfiltrados.append(i)
         self.sh.del_worksheet(worksheet)
-        self.sh.add_worksheet(title=wk, rows=1000, cols=2)
+        self.sh.add_worksheet(title=wk.lower(), rows=1000, cols=2)
         for i in itensfiltrados:
             ad = str(i).split("[")
             ad = str(ad[1]).split("]")
@@ -88,14 +88,23 @@ class Sheets:
                 return True
 
     def __existe(self,se):
-        add, worksheet = addicionar(se)
         try:
+            add, worksheet = addicionar(se)
             worksheet = self.sh.worksheet(worksheet)
             pks = worksheet.col_values(1)
             return True
         except:
-            self.sh.add_worksheet(title=worksheet, rows=1000, cols=2)
-            return False
+            try:
+                worksheet = self.sh.worksheet(se)
+                pks = worksheet.col_values(1)
+                return True
+            except:
+                try:
+                    add, worksheet = addicionar(se)
+                    self.sh.add_worksheet(title=worksheet.lower(), rows=1000, cols=2)
+                except:
+                    self.sh.add_worksheet(title=se.lower(), rows=1000, cols=2)
+                return False
 
     def delete(self,se):
         if self.__existe(se) == True:
@@ -114,6 +123,7 @@ class Sheets:
             return False
 
     def add(self, se):
+        self.restaurar(se)
         self.__existe(se)
         salvar = None
         if se.pk:
@@ -123,14 +133,24 @@ class Sheets:
         self.salvar = salvar
 
     def enviar(self, se):
-        self.restaurar(se)
         if self.salvar == 1:
             self.__updata(se)
         elif self.salvar == 0:
             self.__adicionar(se)
 
     def restaurar(self, se):
-        self.__existe(se)
-        serializers.deserialize("json", self.lertabmod(se), ignorenonexistent=True)
+        try:
+            se = se.lower()
+            self.__existe(se)
+            obj_generator = serializers.deserialize("json", self.lertabmod(se), ignorenonexistent=True)
+            for obj in obj_generator:
+                obj.save()
+            return self.lertabmod(se)
+        except:
+            add, worksheet = addicionar(se)
+            obj_generator = serializers.deserialize("json", self.lertabmod(worksheet), ignorenonexistent=True)
+            for obj in obj_generator:
+                obj.save()
+            return self.lertabmod(worksheet)
 
 google_sheets = Sheets()
\ No newline at end of file
